/**         @file  mkmodgtk.c
 *         @brief
 *          @date  17/11/2017
 *        @author  François Cerbelle (Fanfan), francois@cerbelle.net
 *     @copyright  Copyright (c) 2017, François Cerbelle
 *
 *   @internal
 *       Compiler  gcc
 *  Last modified  2024-07-02 09:51
 *   Organization  Cerbelle.net
 *        Company  Home
 *
 *   This source code is released for free distribution under the terms of the
 *   GNU General Public License as published by the Free Software Foundation.
 */

#include "module.h"
#include "mkmod.h"
#include "gettext.h"
#define _(String) gettext (String)

#include <stdio.h>

#include "debug/assert.h"
#include "debug/memory.h"

#include <math.h>
#pragma GCC diagnostic push                             /* save the actual diag context */
#pragma GCC diagnostic ignored "-Wpedantic"             /* locally disable maybe warnings */
#include <gtk/gtk.h>
#pragma GCC diagnostic pop                              /* restore previous diag context */

/* List exposed module functions */
static void mkmod_function();
mkmod_api_t module_api = {
    mkmod_function
};

static moduleinfo_t moduleinfo = {
    "MyGTKModule",
    "MyGTKModule description",
    0,
    1,
    0,
    "First and Lastname",
    "email@address.tld",
    "http://www.mygtkmodule.com",
    "GPLv3"
};

static void
print_hello (GtkWidget *widget,
             gpointer   data)
{
    (void)widget;
    (void)data;
    g_print (_("Hello world from GTK !!!"));
    g_print ("\n");
}

static void
activate (GtkApplication* app,
          gpointer        user_data)
{
    GtkWidget *window;
    GtkWidget *button;
    GtkWidget *box;

    (void)user_data;
    window = gtk_application_window_new (app);
    gtk_window_set_title (GTK_WINDOW (window), "Window");
    gtk_window_set_default_size (GTK_WINDOW (window), 200, 200);

    box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
    gtk_widget_set_halign (box, GTK_ALIGN_CENTER);
    gtk_widget_set_valign (box, GTK_ALIGN_CENTER);

    gtk_window_set_child (GTK_WINDOW (window), box);

    button = gtk_button_new_with_label (_("Hello world from GTK !!!"));

    g_signal_connect (button, "clicked", G_CALLBACK (print_hello), NULL);
    g_signal_connect_swapped (button, "clicked", G_CALLBACK (gtk_window_destroy), window);

    gtk_box_append (GTK_BOX (box), button);

    gtk_window_present (GTK_WINDOW (window));

}

moduleinfo_t* onLoad ()
{
    DBG_MSG("params()");
    return &moduleinfo;
}

uint8_t onUnload()
{
    DBG_MSG("params()");
    return 0;
}

static void mkmod_function()
{
    GtkApplication *app;
    DBG_MSG("params()");

    printf(_("Hello from mkmod_function\n"));
    app = gtk_application_new ("org.gtk.example", G_APPLICATION_DEFAULT_FLAGS);
    g_signal_connect (app, "activate", G_CALLBACK (activate), NULL);
    /* g_application_run (G_APPLICATION (app), argc, argv); */
    g_application_run (G_APPLICATION (app), 0,NULL);
    g_object_unref (app);

}

